Request
=======

Optional parameter to turn on/off long-polling:

.. list-table::

    * - **Parameter**
      - **Type**
      - **Default**
      - **Description**

    * - longPolling
      - Boolean
      - True
      - Default value: True
 
  